@@ -1,5 +1,5 @@
 `parseFN2STA` <-
-function(fn, ista, icomp, sep="\\.")
+function(fn, ista, icomp, sep="\\.", dir=0)
   {
     ###  get the station name and the component name from the file name
     ### function default assumes that the station name and the component name
@@ -8,7 +8,7 @@ function(fn, ista, icomp, sep="\\.")
 
     ##  ista and icomp are computed from the end of the file name
 
-    
+    ##  if dir>0 then the counting is from the beginning starting with 1
 
     if(missing(ista)) { ista = 1 }
     if(missing(icomp)) { icomp = 0 } 
@@ -18,13 +18,17 @@ function(fn, ista, icomp, sep="\\.")
     fn1 = basename(fn)
     
     f2 = unlist(strsplit(fn1, split=sep))
-
     
-    sta = f2[length(f2)-ista]
-
-    
-    comp = f2[length(f2)-icomp]
-
+    if(dir<1)
+      {
+        sta = f2[length(f2)-ista]
+        comp = f2[length(f2)-icomp]
+      }
+    else
+      {
+        sta = f2[ista]
+        comp = f2[icomp]
+      }
     
     return(list(sta=sta, comp=comp) )
 
