@@ -1,9 +1,13 @@
-winseis24<-function(pjj)
+winseis24<-function(pjj, pch=3, col='red' )
 {
+  if(missing(col)) col = 'red'
+  if(missing(pch))  pch=3 
+
+  
 ###########  after plotting plotseis24, interact with plot by clicking
   ###  pjj y=tick marks in the Y direction y axis
   ###      x=x-axis
-  LL = locator(pch=3, type="p", col='red', cex=2)
+  LL = locator(pch=pch, type="p", col=col, cex=2)
 
   tix = pjj$y
 
